@@ -1,5 +1,5 @@
 use kqueue_sys::{kevent, kqueue};
-use libc::{pid_t, timespec, uintptr_t};
+use libc::{pid_t, uintptr_t};
 use std::convert::{AsRef, Into};
 use std::default::Default;
 use std::fs::File;
@@ -11,6 +11,9 @@ use std::time::Duration;
 
 pub use kqueue_sys::constants::*;
 
+mod time;
+use crate::time::duration_to_timespec;
+
 /// The watched object that fired the event
 #[derive(Debug, Eq, Clone)]
 pub enum Ident {
@@ -527,10 +530,7 @@ fn get_event(watcher: &Watcher, timeout: Option<Duration>) -> Option<Event> {
                 0,
                 &mut kev,
                 1,
-                &timespec {
-                    tv_sec: ts.as_secs() as i64,
-                    tv_nsec: ts.subsec_nanos() as i64,
-                },
+                &duration_to_timespec(ts),
             )
         }
     } else {
